gensim — gensim v1.0 documentation

### Navigation

- index
- modules |
- next |
- gensim v1.0 documentation »

# gensim

For an introduction on what gensim does (or does not do), go to the introduction.

To download and install gensim, consult the install page.

For examples on how to use it, try the tutorials.

## Contents

- Introduction
- API Reference

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- gensim v1.0 documentation »